import { DomIteratorOptions } from './domIterator';
import { IndefiniteNodePredicate, NodePredicate } from './util';
/**
 * The type of the result returned by the `compareNodes` option.
 */
export declare enum CompareNodesResult {
    /**
     * Nodes are identical and should not be marked up in the diff result.
     */
    IDENTICAL = 0,
    /**
     * Nodes are similar and should be marked up in the diff result as modified.
     */
    SIMILAR = 1,
    /**
     * Nodes are different and should be marked up in the diff result as a removal followed by an insertion.
     */
    DIFFERENT = 2
}
declare type IndefiniteCompareNodes = (node1: Node, node2: Node) => CompareNodesResult | undefined;
declare type CompareNodes = (node1: Node, node2: Node) => CompareNodesResult;
/**
 * The options for `visualDomDiff`.
 */
export interface Options {
    /**
     * The class name to use to mark up inserted content.
     * Default is `'vdd-added'`.
     */
    addedClass?: string;
    /**
     * Should the letter case be ignored.
     * Default is `false`.
     */
    ignoreCase?: boolean;
    /**
     * The class name to use to mark up modified content.
     * Default is `'vdd-modified'`.
     */
    modifiedClass?: string;
    /**
     * The class name to use to mark up removed content.
     * Default is `'vdd-removed'`.
     */
    removedClass?: string;
    /**
     * Indicates if the child nodes of the specified `node` should be ignored.
     * It is useful for ignoring child nodes of an element representing some embedded content,
     * which should not be compared. Return `undefined` for the default behaviour.
     */
    skipChildren?: IndefiniteNodePredicate;
    /**
     * Indicates if the specified `node` should be ignored.
     * Even if the `node` is ignored, its child nodes will still be processed,
     * unless `skipChildNodes` says they should also be ignored.
     * Ignored elements whose child nodes are processed are treated as formatting elements.
     * Return `undefined` for the default behaviour.
     */
    skipSelf?: IndefiniteNodePredicate;
    /**
     * Determines whether the specified nodes are identical, similar or different.
     * Return `undefined` for the default behaviour.
     */
    compareNodes?: IndefiniteCompareNodes;
}
export interface Config extends Options, DomIteratorOptions {
    readonly addedClass: string;
    readonly ignoreCase: boolean;
    readonly modifiedClass: string;
    readonly removedClass: string;
    readonly skipChildren: NodePredicate;
    readonly skipSelf: NodePredicate;
    readonly compareNodes: CompareNodes;
}
export declare function optionsToConfig({ addedClass, ignoreCase, modifiedClass, removedClass, skipChildren, skipSelf, compareNodes }?: Options): Config;
export {};
